@@ -1,6 +1,6 @@
 #! /usr/bin/python
 # -*- coding: utf-8 -*-
-# $Id: test_dbapi20.py 901 2017-01-06 12:25:02Z cito $
+# $Id: test_dbapi20.py 929 2018-01-22 09:15:34Z cito $
 
 try:
     import unittest2 as unittest  # for Python < 2.7
@@ -439,7 +439,7 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
     def test_cursor_iteration(self):
         con = self._connect()
         cur = con.cursor()
-        cur.execute("select 1 union select 2 union select 3")
+        cur.execute("select 1 union select 2 union select 3 order by 1")
         self.assertEqual([r[0] for r in cur], [1, 2, 3])
 
     def test_cursor_invalidation(self):
